﻿selectedToonDelete = ""
local ptsets = {}
local pt = LibStub("LibPeriodicTable-3.1", true)

local function getArgValue(info)
	return info
end

--Loops though the available Filters for the Current player and appends them at the end of LWOptionsFilter
function Liquid_Wealth:addFiltersToLWOptionsFilter()
	for filter in pairs(Liquid_Wealth.db.realm.toon[UnitName("player")].filters) do
		if not LWOptionsFilter["args"]["Group_"..filter] then
			LWOptionsFilter["args"]["Group_"..filter]={}
		end
		LWOptionsFilter["args"]["Group_"..filter]={name="",desc="",inline=true,type='group',order=-1,args ={}}
		LWOptionsFilter["args"]["Group_"..filter]["args"][filter]={order=0,type="input",name="",get=function() return filter end}
		LWOptionsFilter["args"]["Group_"..filter]["args"]["up"]={name="Up",desc="",type='execute',width="half",order=2}
		LWOptionsFilter["args"]["Group_"..filter]["args"]["down"]={name="Down",desc="",type='execute',width="half",order=3}
		LWOptionsFilter["args"]["Group_"..filter]["args"]["delete"]={name="Delete",desc="",type='execute',width='half',order=4}
	end
	Liquid_Wealth.db.profile.NewTable=LWOptionsFilter
end

function Liquid_Wealth:DBFilterTest()
	Liquid_Wealth:NewFilter("Cloth","Tradeskill.Mat.ByType.Cloth","PTSet",53010)
	Liquid_Wealth:NewFilter("Gems","Tradeskill.Mat.ByType.Gem","PTSet",71807)
	Liquid_Wealth:NewFilter("Herbs","Tradeskill.Mat.ByType.Herb","PTSet",52986)
	Liquid_Wealth:NewFilter("Enchanting","Tradeskill.Crafted.Enchanting","PTSet",74250)
	Liquid_Wealth:addFiltersToLWOptionsFilter()
end

function Liquid_Wealth:listLoadedAuctions()
  local table = {}
  local noIndex = true
  table["--None--"] = "--None--"
  for _, addon in pairs(Liquid_Wealth.AuctioneerAddons) do
    local _, isloaded = IsAddOnLoaded(addon.name);
    if (isloaded) then --Check To See If Add-on InList Is Enabled
      table[addon.name] = addon.name
      noIndex = false
    end
  end
  return table, noIndex
end

-----------------------------------------------------------------------
-- PTSet

---------------------
-- PT Set Browser  --
---------------------
function Liquid_Wealth:BuildPTSetTable()
	if not (pt) then
		return
	end

	local sets = pt.sets
	for setname in pairs(sets) do
		local workingLevel = ptsets
		local oldLevel, oldParent, allowedFlag
		for parent in setname:gmatch("([^%.]+)") do
			if not workingLevel[parent] then
				workingLevel[parent] = {}
				allowedFlag = true
			else
				allowedFlag = false
			end
			for k, v in pairs(workingLevel) do
				local kname = k:match("0077ff([^%*]+)")
				if kname == parent then
					workingLevel[k] = nil
				end
			end

			oldLevel = workingLevel
			oldParent = parent
			workingLevel = workingLevel[parent]
		end
		if allowedFlag then
			oldLevel[oldParent] = false
		end
	end
end

local currentRule
local function buildMenu(tab, name)
	local menu = {}
	for k,v in pairs(tab) do
		local newName
		if not name then
			newName = k
		else
			newName = ("%s.%s"):format(name, k)
		end
		if not v then
			tinsert(menu, {
				text = k,
				func = function()
						currentRule.setname = newName
					end,
			})
		elseif type(v) == 'table' then
			tinsert(menu, {
				text = k,
				hasArrow = true,
				menuList = buildMenu(v, newName),
				func = function()
						currentRule.setname = newName
					end,
			})
		end
	end
	return menu
end

local ptdropdownFrame = CreateFrame("Frame", "Baggins_PTConfigMenuFrame", UIParent, "UIDropDownMenuTemplate")
local function showPTDropdown(info)
	local menu = buildMenu(ptsets)
	--local categoryname = info[#info-2]:sub(2)
	local ruleid = info[#info-1]
	local attr = info[#info]
	currentRule = info.arg
	EasyMenu(menu, ptdropdownFrame, "cursor", 0, 0, "MENU")
end

function Liquid_Wealth:LoadOptionsTables()
LWOptionsGeneral =
{
  type = 'group',
  name = "Liquid-Wealth: General Settings",
  cmdInline = false,
  args =
  {
    generalheaderDes =
    {
      order = 1,
      type = "description",
      name = "Please change your setting below",
      cmdHidden = true,
    },
    headerDisplay =
    {
      order = 2,
      type = "header",
      name = "Tool-tip Display Options",
      cmdHidden = true,
    },
    simplePlayerBags =
    {
      type = 'toggle',
      name = "Simple Details (Player Bags |TInterface\\Icons\\INV_Misc_Bag_08:25|t)",
      desc = "Enable this to display a simpler view of the Players Bags.",
      order = 3,
      width = "full",
      get = function() return Liquid_Wealth.db.profile.noBagInfoTip end,
      set = function(_, v) Liquid_Wealth.db.profile.noBagInfoTip = v end,
    },
    simplePlayerBank =
    {
      type = 'toggle',
      name = "Simple Details (Player Bank |TInterface\\Icons\\INV_Misc_Bag_08:25|t)",
      desc = "Enable this to display a simpler view of the Players Bank.",
      order = 4,
      width = "full",
      get = function() return Liquid_Wealth.db.profile.noBankInfoTip end,
      set = function(_, v) Liquid_Wealth.db.profile.noBankInfoTip = v end,
    },
    showHintTip =
    {
      type = 'toggle',
      name = "Enable Hint Tips",
      desc = "Enable this to display a a tool-tip below, to show common tasks or functions.",
      order = 5,
      width = "full",
      get = function() return Liquid_Wealth.db.profile.displayHints end,
      set = function(_, v) Liquid_Wealth.db.profile.displayHints = v end,
    },
    headerPriceOptions =
    {
      order = 6,
      type = "header",
      name = "Vendor & Auction Add-on Settings",
      cmdHidden = true,
    },
    auctionselect =
    {
      order = 7,
      type = "select",
      name = "Auction Add-on List",
      desc = "Select Auction Pricing Add-on.",
      disabled = function()
        _, noindex = Liquid_Wealth:listLoadedAuctions()
        return noindex
      end,
      get = function() return Liquid_Wealth.db.profile.selectedAuctionAddon end,
      set = function(_, v) Liquid_Wealth.db.profile.selectedAuctionAddon = v end,
      values = function() return Liquid_Wealth:listLoadedAuctions() end,
    },
    headerScanningOptions =
    {
      order = 8,
      type = "header",
      name = "Scanning Options",
      cmdHidden = true,
    },
    EnableGuildBankScanning =
    {
      type = 'toggle',
      name = "Enable Guild Bank Scanning",
      desc = "Enable this to scan the guild bank.",
      order = 9,
      width = "full",
      get = function() return Liquid_Wealth.db.profile.scanGuildBank end,
      set = function(_, v) Liquid_Wealth.db.profile.scanGuildBank = v end,
    },
    generalheader2 =
    {
      order = 10,
      type = "header",
      name = "Force Scanning Options",
      cmdHidden = true,
    },
    forceLocalScan =
    {
      type = "execute",
      name = "Player Bags Scan",
      order = 11,
      desc = "This command will force a scan of the players bags.",
      func = function() Liquid_Wealth:forceScan(1) end,
    },
	HeaderDebug =
    {
      order = 12,
      type = "header",
      name = "Debug Options",
      cmdHidden = true,
    },
	tooltipDebug =
    {
      type = 'toggle',
      name = "Enable Tool-tip Debugging",
      desc = "Enable this to show Tool-tip Debugging.",
      order = 13,
      width = "full",
      get = function() return Liquid_Wealth.db.profile.toolTipDebugEnabled end,
      set = function(_, v) Liquid_Wealth.db.profile.toolTipDebugEnabled = v end,
    },
  },
}

LWOptionsSkins = {
  name = "Liquid-Wealth: ToolTip Skinning",
  type = 'group',
  desc = "Options for Skinning The ToolTip",
  args =
  {
    generalheader =
    {
      order = 1,
      type = "header",
      name = "ToolTip Skinning Settings",
      cmdHidden = true,
    },
    TicTacSkinning =
    {
      type = 'toggle',
      name = "Enable TicTac Skinning",
      desc = "Enables the skinning of the tool-tip using TicTac for Skinning. Note: If you want to clear the skin you have to disable this, and then Reload UI",
      order = 2,
      disabled = function() return not (_G.TipTac and _G.TipTac.AddModifiedTip) end,
      get = function() return Liquid_Wealth.db.profile.TipTacSkin end,
      set = function(_, v) Liquid_Wealth.db.profile.TipTacSkin = v end,
    },
  },
}

CommandLineOptionsRTC = {
  name = "Remote Characters Configuration",
  type = "group",
  args = {
    confdesc = {
      order = 1,
      type = "description",
      name = "Please change your setting below",
      cmdHidden = true,
    },
    generalheader = {
      order = 2,
      type = "header",
      name = "Vendor & Auction Add-on Settings",
    },
    nulloption = {
      order = 3,
      type = "description",
      name = " ",
      cmdHidden = true,
    },
    RanTest = {
      type = "execute",
      name = "Ran Test",
      order = 9,
      desc = "Ran Text.",
      func = function()
        serializedData = Liquid_Wealth:Serialize("NPS")
        Liquid_Wealth:SendCommMessage("LMAC", serializedData, "WHISPER", "wildorebar")
      end,
    },
  }
}

LWOptionsFilter = {
	name = "Liquid-Wealth: Filters",
	type = 'group',
	desc = "Settings for Filters Module",
	args =
	{
		generalheader =
		{
			order = 1,
			type = "header",
			name = "Filter Settings",
			cmdHidden = true,
		},
		addDefaultPTSetsToFilter =
		{
		  type = "execute",
		  name = "Add Default Filter",
		  order = 2,
		  desc = "Add Default PT3 Sets to Filter",
		  func = function() Liquid_Wealth:DBFilterTest() end,
		},
		addNewFilter =
		{
		  type = "execute",
		  name = "Add New Filter",
		  order = 3,
		  desc = "Add New Filter",
		  func = showPTDropdown,
		},
		GroupNewFilter={
			name = "",
			desc = "",
			inline = true,
			type = 'group',
			order = 4,
			args = {
				NewName={order=1,type="input",name="Name:",get=function() return "New" end},
				NewPT={order=2,type="select",name="PT Set:",style="dropdown",values={"Test"}},
				NewType={order=3,type="select",name="Type:",style="dropdown",values={"Test"}},
				NewIcons={order=4,type="input",name="Icon:"},
			},
		},
		Filterheader =
		{
			order = 5,
			type = "header",
			name = "Filter List",
			cmdHidden = true,
		},
	}
}
  LWOptionsDatabase = {
  name = "Liquid-Wealth: Database",
  type = 'group',
  desc = "Settings to allow add-on debugging",
  args =
  {
    generalheader =
    {
      order = 1,
      type = "header",
      name = "Database Settings",
      cmdHidden = true,
    },
    lwConfigVerbs =
    {
      order = 2,
      type = "description",
      name = "Liquid-Wealth Version: " .. GetAddOnMetadata("Liquid_Wealth", "Version") .. "\nLiquid-Wealth (Final) Database Version: " .. currentDBVersion .. "\nLiquid-Wealth Database Version: "..Liquid_Wealth.db.global.dbversion,
      fontSize = "medium",
      cmdHidden = true,
    },
    resetDatabases =
    {
      type = 'execute',
      name = "Reset All Data",
      desc = "This will clear all databases with in Liquid-Wealth. Use this if you are having database problems, or if you have old databases.",
      order = 3,
      func = function()
        Liquid_Wealth:resetMasterDatabases()
      end,
    },
    removeCharFromDB =
    {
      order = 4,
      type = "select",
      name = "Reset Selected Characters Data",
      desc = "Select Characters To Remove From Database.",
      set = function(_, v)
        local tableList = {}
        for i, _ in pairs(Liquid_Wealth.db.realm.toon) do
          table.insert(tableList, i)
        end
        Liquid_Wealth:removeToonFromDB(tableList[v])
      end,
      values = function()
        local tableList = {}
        for i, _ in pairs(Liquid_Wealth.db.realm.toon) do
          local toonWIcon = Liquid_Wealth:BuildIcons(Liquid_Wealth.db.realm.toon[i].unitID) .. " " .. "|c" .. Liquid_Wealth:ClassColor(Liquid_Wealth.db.realm.toon[i].unitID) .. i .. "|r"
          table.insert(tableList, toonWIcon)
        end
        return tableList
      end,
    },
    removeGuildFromDB =
    {
      order = 5,
      type = "select",
      name = "Reset Selected Guild Data",
      desc = "Select Guild To Remove From Database.",
      set = function(_, v)
        if tablelength(Liquid_Wealth.db.realm.guild) > 0 then
          local tableList = {}
          for i, _ in pairs(Liquid_Wealth.db.realm.guild) do
            table.insert(tableList, i)
          end
          Liquid_Wealth:removeGuildFromDB(tableList[v])
        end
      end,
      values = function()
        local tableList = {}
        if tablelength(Liquid_Wealth.db.realm.guild) > 0 then
          for i, _ in pairs(Liquid_Wealth.db.realm.guild) do
            table.insert(tableList, i)
          end
        else
          table.insert(tableList, "No Guild Data")
        end
        return tableList
      end,
    },
  },
}
	--Loops though the available Filters for the Current player and adds them to the LWOptionsFilter menu before it gets loaded into ACE3 config.
	Liquid_Wealth:BuildPTSetTable()
	Liquid_Wealth:addFiltersToLWOptionsFilter()
	local AceConfig = LibStub("AceConfig-3.0")
	AceConfig:RegisterOptionsTable("LiquidWealth", LWOptionsGeneral, { "lw", "liquidwealth" })
	LibStub("AceConfigRegistry-3.0"):RegisterOptionsTable("LiquidWealth Skin", LWOptionsSkins)
	LibStub("AceConfigRegistry-3.0"):RegisterOptionsTable("LiquidWealth Database", LWOptionsDatabase)
	LibStub("AceConfigRegistry-3.0"):RegisterOptionsTable("LiquidWealth Filters", LWOptionsFilter)
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions("LiquidWealth", "LiquidWealth")
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions("LiquidWealth Skin", "ToolTip Skinning", "LiquidWealth")
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions("LiquidWealth Database", "Database", "LiquidWealth")
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions("LiquidWealth Filters", "Filters", "LiquidWealth")
	LibStub("LibAboutPanel").new("LiquidWealth", "Liquid_Wealth")
end